@@ -20,7 +20,7 @@ from signaux.signal_complet import SignalComplet
 import numpy as np
 
 
-__all__ = ["GBF"]
+__all__ = ["SignalGBF"]
 
 liste_types_signaux_gbf = ["cosinus", "carre", "triangle"]
 
@@ -184,7 +184,7 @@ class SignalTriangle(SignalComplet):
 
         self.mesures.T_th = T
 
-class GBF(SignalComplet):
+class SignalGBF(SignalComplet):
     def __init__(self, type_signal = "cosinus", F=1, Vpp= 1, offset = 0, tr=0., phi = 0., alpha = 0.5, liste_tmin_tmax = cst.liste_tmin_tmax, Te = cst.Te, nom = ""):
         if type_signal not in liste_types_signaux_gbf:
             print("Ce type de signaux n'existe pas")
@@ -199,7 +199,7 @@ class GBF(SignalComplet):
 if __name__ == "__main__":
     bdt = BaseTemps(cst.liste_tmin_tmax, cst.Te)
 
-    s = GBF("triangle", 1, Vpp = 5, liste_tmin_tmax = [0,0.99], tr = -0.2, alpha = 0.5, phi=-np.pi/2)
+    s = SignalGBF("triangle", 1, Vpp = 5, liste_tmin_tmax = [0,0.99], tr = -0.2, alpha = 0.5, phi=-np.pi/2)
     s.tracer_signal()
     # liste_tmin_tmax=[0, 1]
     # F = 2
